import { Integration } from '../../integration';
import { HTTPMethodValue } from '../props';
export interface IMethodIntegrations {
    get?: Integration;
    post?: Integration;
    put?: Integration;
    delete?: Integration;
    options?: Integration;
    head?: Integration;
    patch?: Integration;
    trace?: Integration;
}
/**
 * Methods with integrations.
 *
 * Has to be a class because of JSII limitations.
 *
 * Because of JSII5000 all getters are renamed to non-getXxx named methods.
 */
export declare class Methods {
    private readonly methods;
    constructor(methods: IMethodIntegrations);
    /**
     * Add or update an integration for a specific HTTP method
     */
    setIntegration(method: HTTPMethodValue, integration: Integration): void;
    /**
     * Get an integration for a specific HTTP method
     */
    fetchIntegration(method: HTTPMethodValue): Integration | undefined;
    /**
     * Check if there is an integration for a specific HTTP method
     */
    hasIntegration(method: HTTPMethodValue): boolean;
    /**
     * Remove integration from a specific HTTP method
     */
    removeIntegration(method: HTTPMethodValue): boolean;
    /**
     * Get all integrations
     */
    fetchAllIntegrations(): IMethodIntegrations;
}
